@@ -18,8 +18,8 @@
 **
 ** You should have received a copy of the GNU General Public License
 ** along with this program in a file called COPYING; if not, write to
-** the Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
-** MA 02111-1307, USA.
+** the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+** MA 02110-1301, USA.
 */
 
 /*
@@ -61,13 +61,13 @@ QPtrList<MapTheme> MapLoader::themes()
 }
 
 
-QStringList MapLoader::maps(QString theme)
+QStringList MapLoader::maps(const QString &theme)
 {
   return KGlobal::dirs()->findAllResources("data", QString("kworldclock/maps/%1/*.jpg").arg(theme));
 }
 
 
-void MapLoader::load(unsigned int width, QString theme, unsigned int height, float opacity)
+void MapLoader::load(unsigned int width, const QString &theme, unsigned int height, float opacity)
 {
   // find the maps available
   QValueList<uint> sizes;
@@ -169,3 +169,4 @@ QBitmap MapLoader::darkMask(int width, int height)
   delete [] wtab;
   return illuMask;
 }
+
